'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = shift;

var _jscodeshift = require('jscodeshift');

var _jscodeshift2 = _interopRequireDefault(_jscodeshift);

var _callExpressionToMemberExpression = require('./call-expression-to-member-expression');

var _callExpressionToMemberExpression2 = _interopRequireDefault(_callExpressionToMemberExpression);

var _toBeDefined = require('./to-be-defined');

var _toBeDefined2 = _interopRequireDefault(_toBeDefined);

var _toBeFalsy = require('./to-be-falsy');

var _toBeFalsy2 = _interopRequireDefault(_toBeFalsy);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var MemberExpression = _jscodeshift2.default.MemberExpression;


var NAMES = {
  'toBe': 'be',
  'toEqual': 'equal',
  'toMatch': 'match',
  'toBeNull': 'be.null',
  'toBeTruthy': 'be.ok',
  'toContain': 'include',
  'toBeLessThan': 'be.below',
  'toBeGreaterThan': 'be.above',
  'toBeCloseTo': 'be.closeTo',
  'toThrow': 'throw',
  'toThrowError': 'throw'
};

var MATCHERS = Object.keys(NAMES).reduce(function (memo, name) {
  memo[name] = translate(NAMES[name]);
  return memo;
}, Object.create(null));

MATCHERS.toBeDefined = _toBeDefined2.default;
MATCHERS.toBeFalsy = _toBeFalsy2.default;

var MATCHER_NAMES = Object.keys(MATCHERS);

function shift(source) {
  var $ = (0, _jscodeshift2.default)(source);
  (0, _callExpressionToMemberExpression2.default)($);

  return $.find(MemberExpression).filter(function (node) {
    return MATCHER_NAMES.indexOf(node.value.property.name) !== -1;
  }).replaceWith(function (node) {
    return MATCHERS[node.value.property.name](node);
  }).toSource();
}

function jasmine2ChaiName(jasmineName) {
  return NAMES[jasmineName];
}

function translate(newName) {
  return function (node) {
    var name = jasmine2ChaiName(node.value.property.name);
    var expectExpression = node.value.object;
    var to = _jscodeshift2.default.memberExpression(expectExpression, _jscodeshift2.default.identifier('to'));
    var assertion = _jscodeshift2.default.memberExpression(to, _jscodeshift2.default.identifier(name));
    return assertion;
  };
}